==> haskell-http-client-tls-0.3.6.4-129-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-client-tls
version:              0.3.6.4
visibility:           public
id:                   http-client-tls-0.3.6.4-2TpGPIcpPZAJDvilQsJ18b
key:                  http-client-tls-0.3.6.4-2TpGPIcpPZAJDvilQsJ18b
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/http-client
synopsis:
    http-client backend using the connection package and tls library

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/http-client-tls>.

category:             Network
abi:                  d22fca1ceeb573ec681eaf8cc4f0258b
exposed:              True
exposed-modules:      Network.HTTP.Client.TLS
import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-client-tls-0.3.6.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-client-tls-0.3.6.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-client-tls-0.3.6.4
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/loongarch64-linux-ghc-9.6.6/http-client-tls-0.3.6.4

hs-libraries:         HShttp-client-tls-0.3.6.4-2TpGPIcpPZAJDvilQsJ18b
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-3fPl2hvou1nDiCO1iE2i5z containers-0.6.7
    crypton-1.0.4-11gen3PFWz54w2m32bVEwY
    crypton-connection-0.4.5-2c10WiKFU3L73agHYaksHE
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz exceptions-0.10.7
    http-client-0.7.19-ITPZXASBEGHLmOi4NfdGY8
    http-types-0.12.4-AM56akyPNdKBTyuGfrlHOS
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe
    network-uri-2.6.4.2-69jfmnohyG88ZQKNy7a5sS text-2.0.2
    tls-2.0.6-HHKVvNcSfLyJGme2UrIiax transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-http-client-tls/html/http-client-tls.haddock

haddock-html:         /usr/share/doc/haskell-http-client-tls/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-client-tls-0.3.6.4-130-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-client-tls
version:              0.3.6.4
visibility:           public
id:                   http-client-tls-0.3.6.4-GXwyMNGv8mPI3u8Rlj5noc
key:                  http-client-tls-0.3.6.4-GXwyMNGv8mPI3u8Rlj5noc
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/http-client
synopsis:
    http-client backend using the connection package and tls library

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/http-client-tls>.

category:             Network
abi:                  51bc2357cb49d28995238d6b84a1f1e4
exposed:              True
exposed-modules:      Network.HTTP.Client.TLS
import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-client-tls-0.3.6.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-client-tls-0.3.6.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-client-tls-0.3.6.4
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/loongarch64-linux-ghc-9.6.6/http-client-tls-0.3.6.4

hs-libraries:         HShttp-client-tls-0.3.6.4-GXwyMNGv8mPI3u8Rlj5noc
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-KNymwxzPyypAOJSQGx0ioI containers-0.6.7
    crypton-1.0.4-8iIZddQo7Y8B1JLRcnCUbI
    crypton-connection-0.4.5-EMMKhGKvDZ19xloyuzywis
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz exceptions-0.10.7
    http-client-0.7.19-9XP2fRtq348Edv4XKGE8tD
    http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ
    network-uri-2.6.4.2-ImBkmHhWmdwGJdqs22FerI text-2.0.2
    tls-2.0.6-CMnie4Wyps5DmePV9nSMbU transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-http-client-tls/html/http-client-tls.haddock

haddock-html:         /usr/share/doc/haskell-http-client-tls/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
